@@ -85,16 +85,19 @@ class DApi2Side(IntEnum):
 class DApi2ErrorLevel(IntEnum):
     '''Error level'''
     
-    info = 0
+    OK = 0
+    '''No error'''
+    
+    INFO = 1
     '''Just an information.'''  
     
-    warning = 1
+    WARNING = 2
     '''A warning can be resolved without intervention.'''
     
-    error = 2
+    ERROR = 3
     '''An error is acknowledged by deactivating the workspace.'''
     
-    fatal = 3
+    FATAL = 4
     '''A fatal error requires restarting the board.'''
     
     @classmethod
@@ -106,7 +109,10 @@ class DApi2ErrorLevel(IntEnum):
         :return: The error level.
         :rtype: DApi2ErrorLevel 
         '''
-        return DApi2ErrorLevel( error >> 6 )
+        if error == 0:
+            return DApi2ErrorLevel.OK
+        else:
+            return DApi2ErrorLevel( (error >> 6)+1 )
     
     @property
     def label(self):
@@ -115,8 +121,14 @@ class DApi2ErrorLevel(IntEnum):
 
     @property
     def help(self):
-        '''The help message of this error level.'''
-        return self.__doc__
+        '''Help message according error level'''
+        return {
+            self.OK : 'No error.',
+            self.INFO : 'Normal state, just an information. No action needed.',
+            self.WARNING : 'Warning state. No action needed.',
+            self.ERROR : 'Error state. The board must be placed in "standby" to clear the error.',
+            self.FATAL : 'Fatal error state. The board must be shutdown to clear the error.',
+            }[self]    
 
 
 class DApiException(Exception):
