@@ -348,8 +348,8 @@ class BaseDBoard(object):
         
     def getSpeedReference(self, refresh=False):
         if refresh: 
-            self.dapi.readReg(self.regs.elcr)
-        return self.regs.elcr.value        
+            self.dapi.readReg(self.regs.ref)
+        return self.regs.ref.value        
 
     def getPressure(self, refresh=False):
         if refresh: 
